module.exports = [
	[/Module parse failed/, /dump-file\.txt/, /templates sync \^\\\.\\\/\.\*\$/],
	[/Critical dependency/, /templateLoader\.js/],
	[/Critical dependency/, /templateLoaderIndirect\.js/],
	[/Critical dependency/, /templateLoaderIndirect\.js/],
];
